@@ -1,25 +1,17 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Setup preferences form
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Config\Forms\Setup;
 
 use PhpMyAdmin\Config\Forms\BaseFormList;
 
-/**
- * Class SetupFormList
- * @package PhpMyAdmin\Config\Forms\Setup
- */
 class SetupFormList extends BaseFormList
 {
-    /**
-     * @var array
-     */
+    /** @var string[] */
     protected static $all = [
         'Config',
         'Export',
@@ -30,8 +22,6 @@ class SetupFormList extends BaseFormList
         'Servers',
         'Sql',
     ];
-    /**
-     * @var string
-     */
-    protected static $ns = '\\PhpMyAdmin\\Config\\Forms\\Setup\\';
+    /** @var string */
+    protected static $ns = 'PhpMyAdmin\\Config\\Forms\\Setup\\';
 }
